import { BrowserRouter as Router, Routes, Route } from "react-router-dom";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import EnhancedErrorBoundary from "./components/common/EnhancedErrorBoundary";
import { RecoveryManager } from "./components/common/RecoveryManager";
import { ReliabilityStatus } from "./components/common/ReliabilityStatus";
import { initializeSiteAssets } from "./utils/siteAssetsInit";
import { useEffect, useState } from "react";
import { toast } from "sonner";
import { HelmetProvider } from "react-helmet-async";

import Index from "./pages/Index";
import NotFound from "./pages/NotFound";
import Chat from "./pages/Chat";
import Login from "./pages/Login";
import Register from "./pages/Register";
import ForgotPassword from "./pages/ForgotPassword";
import ResetPassword from "./pages/ResetPassword";
import Providers from "./pages/Providers";
import Profile from "./pages/Profile";
import About from "./pages/About";
import Contact from "./pages/Contact";
import AdminPanel from "./pages/AdminPanel";
import Dashboard from "./pages/Dashboard";
import PreventionGuide from "./pages/PreventionGuide";
import Knowledgebase from "./pages/Knowledgebase";
import AddBusiness from "./pages/AddBusiness";
import PrivacyPolicy from "./pages/PrivacyPolicy";
import DataDeletion from "./pages/DataDeletion";
import CaseStudies from "./pages/CaseStudies";
import CaseStudyDetail from "./pages/CaseStudyDetail";
import MonitoringDashboard from "./pages/MonitoringDashboard";
import FAQ from "./pages/FAQ";
import FleasPage from "./pages/pests/FleasPage";
import TicksPage from "./pages/pests/TicksPage";
import RodentsPage from "./pages/pests/RodentsPage";
import AntsPage from "./pages/pests/AntsPage";
import CockroachesPage from "./pages/pests/CockroachesPage";
import SpidersPage from "./pages/pests/SpidersPage";
import MosquitoesPage from "./pages/pests/MosquitoesPage";
import BedBugsPage from "./pages/pests/BedBugsPage";
import TermitesPage from "./pages/pests/TermitesPage";
import WaspsPage from "./pages/pests/WaspsPage";
import FliesPage from "./pages/pests/FliesPage";
import SilverfishPage from "./pages/pests/SilverfishPage";
import MothsPage from "./pages/pests/MothsPage";

import { AuthProvider } from "./contexts/auth/AuthContext";
import { AuthorizationProvider } from "./contexts/auth/AuthorizationContext";
import { AuthorizationGuard } from "./components/auth/AuthorizationGuard";
import { SecurityMonitor } from "./components/monitoring/SecurityMonitor";
import { Toaster } from "./components/ui/toaster";
import { CookieConsent } from "./components/common/CookieConsent";
import { ScrollToTop } from "./components/common/ScrollToTop";

import "./App.css";

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      retry: 1,
      refetchOnWindowFocus: false,
      staleTime: 5 * 60 * 1000, // 5 minutes
    },
  },
});

const App = () => {
  const [initError, setInitError] = useState<string | null>(null);

  useEffect(() => {
    const init = async () => {
      try {
        await initializeSiteAssets();
      } catch (err) {
        const errorMessage = err instanceof Error ? err.message : String(err);
        console.error("Error initializing site assets:", errorMessage);
        setInitError(errorMessage);
        
        if (!errorMessage.includes("already exists")) {
          toast.error("Some features may not work correctly", {
            description: "Site initialization encountered an issue",
            duration: 5000,
          });
        }
      }
    };
    
    init();
  }, []);

  return (
    <div className="App">
      <EnhancedErrorBoundary>
        <QueryClientProvider client={queryClient}>
          <AuthProvider>
            <AuthorizationProvider>
              <HelmetProvider>
                <Router>
                <ScrollToTop />
                <RecoveryManager />
                <ReliabilityStatus serviceName="PestGuard" showDetails={false} />
                <AuthorizationGuard>
                  <SecurityMonitor />
                  
                  <Routes>
                  <Route path="/" element={<Index />} />
                  <Route path="/chat" element={<Chat />} />
                  <Route path="/login" element={<Login />} />
                  <Route path="/register" element={<Register />} />
                  <Route path="/forgot-password" element={<ForgotPassword />} />
                  <Route path="/reset-password" element={<ResetPassword />} />
                  <Route path="/providers" element={<Providers />} />
                  <Route path="/profile" element={<Profile />} />
                  <Route path="/about" element={<About />} />
                  <Route path="/contact" element={<Contact />} />
                  <Route path="/faq" element={<FAQ />} />
                  <Route path="/admin" element={<AdminPanel />} />
                  <Route path="/dashboard" element={<Dashboard />} />
                  <Route path="/monitoring" element={<MonitoringDashboard />} />
                  <Route path="/prevention-guide" element={<PreventionGuide />} />
                  <Route path="/knowledgebase" element={<Knowledgebase />} />
                  <Route path="/add-business" element={<AddBusiness />} />
                  <Route path="/privacy-policy" element={<PrivacyPolicy />} />
                  <Route path="/data-deletion" element={<DataDeletion />} />
                  <Route path="/case-studies" element={<CaseStudies />} />
                  <Route path="/case-studies/:slug" element={<CaseStudyDetail />} />
                  <Route path="/pests/fleas" element={<FleasPage />} />
                  <Route path="/pests/ticks" element={<TicksPage />} />
                  <Route path="/pests/rodents" element={<RodentsPage />} />
                  <Route path="/pests/ants" element={<AntsPage />} />
                  <Route path="/pests/cockroaches" element={<CockroachesPage />} />
                  <Route path="/pests/spiders" element={<SpidersPage />} />
                  <Route path="/pests/mosquitoes" element={<MosquitoesPage />} />
                  <Route path="/pests/bed-bugs" element={<BedBugsPage />} />
                  <Route path="/pests/termites" element={<TermitesPage />} />
                  <Route path="/pests/wasps" element={<WaspsPage />} />
                  <Route path="/pests/flies" element={<FliesPage />} />
                  <Route path="/pests/silverfish" element={<SilverfishPage />} />
                  <Route path="/pests/moths" element={<MothsPage />} />
                    <Route path="*" element={<NotFound />} />
                  </Routes>
                  <CookieConsent />
                </AuthorizationGuard>
                </Router>
                <Toaster />
              </HelmetProvider>
            </AuthorizationProvider>
          </AuthProvider>
        </QueryClientProvider>
      </EnhancedErrorBoundary>
    </div>
  );
};

export default App;
